summaryrefslogtreecommitdiffstats
path: root/drivers/char/joystick
diff options
context:
space:
mode:
authorRalf Baechle <ralf@linux-mips.org>2000-01-29 01:41:54 +0000
committerRalf Baechle <ralf@linux-mips.org>2000-01-29 01:41:54 +0000
commitf969d69ba9f952e5bdd38278e25e26a3e4a61a70 (patch)
treeb3530d803df59d726afaabebc6626987dee1ca05 /drivers/char/joystick
parenta10ce7ef2066b455d69187643ddf2073bfc4db24 (diff)
Merge with 2.3.27.
Diffstat (limited to 'drivers/char/joystick')
-rw-r--r--drivers/char/joystick/joy-amiga.c4
-rw-r--r--drivers/char/joystick/joy-analog.c4
-rw-r--r--drivers/char/joystick/joy-analog.h4
-rw-r--r--drivers/char/joystick/joy-assasin.c6
-rw-r--r--drivers/char/joystick/joy-gravis.c2
-rw-r--r--drivers/char/joystick/joy-lightning.c4
-rw-r--r--drivers/char/joystick/joy-logitech.c4
-rw-r--r--drivers/char/joystick/joy-sidewinder.c4
-rw-r--r--drivers/char/joystick/joy-thrustmaster.c4
-rw-r--r--drivers/char/joystick/joy-turbografx.c4
-rw-r--r--drivers/char/joystick/joystick.c4
11 files changed, 22 insertions, 22 deletions
diff --git a/drivers/char/joystick/joy-gravis.c b/drivers/char/joystick/joy-gravis.c
index 9185d3113..7416527e4 100644
--- a/drivers/char/joystick/joy-gravis.c
+++ b/drivers/char/joystick/joy-gravis.c
@@ -25,7 +25,7 @@
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*
* Should you need to contact me, the author, you can do so either by
- * e-mail - mail your message to <vojtech@ucw.cz>, or by paper mail:
+ * e-mail - mail your message to <vojtech@suse.cz>, or by paper mail:
* Vojtech Pavlik, Ucitelska 1576, Prague 8, 182 00 Czech Republic
*/
diff --git a/drivers/char/joystick/joy-amiga.c b/drivers/char/joystick/joy-amiga.c
index 520f262a4..918025040 100644
--- a/drivers/char/joystick/joy-amiga.c
+++ b/drivers/char/joystick/joy-amiga.c
@@ -25,7 +25,7 @@
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*
* Should you need to contact me, the author, you can do so either by
* e-mail - mail your message to <vojtech@ucw.cz>, or by paper mail:
* Vojtech Pavlik, Ucitelska 1576, Prague 8, 182 00 Czech Republic
*/
@@ -39,7 +39,7 @@
static struct js_port* js_am_port __initdata = NULL;
-MODULE_AUTHOR("Vojtech Pavlik <vojtech@ucw.cz>");
+MODULE_AUTHOR("Vojtech Pavlik <vojtech@suse.cz>");
MODULE_PARM(js_am, "1-2i");
static int js_am[]={0,0};
@@ -25,7 +25,7 @@
*
* Should you need to contact me, the author, you can do so either by
- * e-mail - mail your message to <vojtech@ucw.cz>, or by paper mail:
+ * e-mail - mail your message to <vojtech@suse.cz>, or by paper mail:
* Vojtech Pavlik, Ucitelska 1576, Prague 8, 182 00 Czech Republic
*/
diff --git a/drivers/char/joystick/joy-analog.c b/drivers/char/joystick/joy-analog.c
index fdf04b212..7c1c9719d 100644
--- a/drivers/char/joystick/joy-analog.c
+++ b/drivers/char/joystick/joy-analog.c
@@ -25,7 +25,7 @@
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*
* Should you need to contact me, the author, you can do so either by
* e-mail - mail your message to <vojtech@ucw.cz>, or by paper mail:
* Vojtech Pavlik, Ucitelska 1576, Prague 8, 182 00 Czech Republic
*/
@@ -43,7 +43,7 @@
static int js_an_port_list[] __initdata = {0x201, 0};
static struct js_port* js_an_port __initdata = NULL;
-MODULE_AUTHOR("Vojtech Pavlik <vojtech@ucw.cz>");
+MODULE_AUTHOR("Vojtech Pavlik <vojtech@suse.cz>");
MODULE_PARM(js_an, "2-24i");
static int js_an[]={-1,0,0,-1,0,0,-1,0,0,-1,0,0,-1,0,0,-1,0,0,-1,0,0,-1,0,0,-1,0,0};
@@ -25,7 +25,7 @@
*
* Should you need to contact me, the author, you can do so either by
- * e-mail - mail your message to <vojtech@ucw.cz>, or by paper mail:
+ * e-mail - mail your message to <vojtech@suse.cz>, or by paper mail:
* Vojtech Pavlik, Ucitelska 1576, Prague 8, 182 00 Czech Republic
*/
diff --git a/drivers/char/joystick/joy-analog.h b/drivers/char/joystick/joy-analog.h
index 06c0079a4..84479fcd1 100644
--- a/drivers/char/joystick/joy-analog.h
+++ b/drivers/char/joystick/joy-analog.h
@@ -26,7 +26,7 @@
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*
* Should you need to contact me, the author, you can do so either by
* e-mail - mail your message to <vojtech@ucw.cz>, or by paper mail:
* Vojtech Pavlik, Ucitelska 1576, Prague 8, 182 00 Czech Republic
*/
@@ -238,7 +238,7 @@ static int __init js_an_probe_devs(struct js_an_info *info, int exist, int mask0
break;
default:
printk(KERN_WARNING "joy-analog: Unknown joystick device detected "
- "(data=%#x), contact <vojtech@ucw.cz>\n", exist);
+ "(data=%#x), contact <vojtech@suse.cz>\n", exist);
return -1;
}
}
@@ -26,7 +26,7 @@
*
* Should you need to contact me, the author, you can do so either by
- * e-mail - mail your message to <vojtech@ucw.cz>, or by paper mail:
+ * e-mail - mail your message to <vojtech@suse.cz>, or by paper mail:
* Vojtech Pavlik, Ucitelska 1576, Prague 8, 182 00 Czech Republic
*/
diff --git a/drivers/char/joystick/joy-assasin.c b/drivers/char/joystick/joy-assasin.c
index 64d16d7b0..731c6e56a 100644
--- a/drivers/char/joystick/joy-assasin.c
+++ b/drivers/char/joystick/joy-assasin.c
@@ -25,7 +25,7 @@
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*
* Should you need to contact me, the author, you can do so either by
* e-mail - mail your message to <vojtech@ucw.cz>, or by paper mail:
* Vojtech Pavlik, Ucitelska 1576, Prague 8, 182 00 Czech Republic
*/
@@ -49,7 +49,7 @@
#define JS_AS_MODE_OEM 3 /* Panther OEM version */
#define JS_AS_MODE_PXL 4 /* Panther XL */
-MODULE_AUTHOR("Vojtech Pavlik <vojtech@ucw.cz>");
+MODULE_AUTHOR("Vojtech Pavlik <vojtech@suse.cz>");
MODULE_PARM(js_as, "2-24i");
static int js_as[]={-1,0,0,-1,0,0,-1,0,0,-1,0,0,-1,0,0,-1,0,0,-1,0,0,-1,0,0,-1,0,0};
@@ -319,7 +319,7 @@ static struct js_port __init *js_as_probe(int io, int mask0, int mask1, struct j
info = port->info;
} else {
printk(KERN_WARNING "joy-assasin: unknown joystick device detected "
- "(io=%#x, id=%d), contact <vojtech@ucw.cz>\n", io, data[0]);
+ "(io=%#x, id=%d), contact <vojtech@suse.cz>\n", io, data[0]);
return port;
}
@@ -25,7 +25,7 @@
*
* Should you need to contact me, the author, you can do so either by
- * e-mail - mail your message to <vojtech@ucw.cz>, or by paper mail:
+ * e-mail - mail your message to <vojtech@suse.cz>, or by paper mail:
* Vojtech Pavlik, Ucitelska 1576, Prague 8, 182 00 Czech Republic
*/
diff --git a/drivers/char/joystick/joy-lightning.c b/drivers/char/joystick/joy-lightning.c
index fc36c3d50..3b337fd9f 100644
--- a/drivers/char/joystick/joy-lightning.c
+++ b/drivers/char/joystick/joy-lightning.c
@@ -26,7 +26,7 @@
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*
* Should you need to contact me, the author, you can do so either by
* e-mail - mail your message to <vojtech@ucw.cz>, or by paper mail:
* Vojtech Pavlik, Ucitelska 1576, Prague 8, 182 00 Czech Republic
*/
@@ -52,7 +52,7 @@
static struct js_port* __initdata js_l4_port = NULL;
-MODULE_AUTHOR("Vojtech Pavlik <vojtech@ucw.cz>");
+MODULE_AUTHOR("Vojtech Pavlik <vojtech@suse.cz>");
MODULE_PARM(js_l4, "2-24i");
static int js_l4[]={-1,0,0,-1,0,0,-1,0,0,-1,0,0,-1,0,0,-1,0,0,-1,0,0,-1,0,0,-1,0,0};
@@ -26,7 +26,7 @@
*
* Should you need to contact me, the author, you can do so either by
- * e-mail - mail your message to <vojtech@ucw.cz>, or by paper mail:
+ * e-mail - mail your message to <vojtech@suse.cz>, or by paper mail:
* Vojtech Pavlik, Ucitelska 1576, Prague 8, 182 00 Czech Republic
*/
diff --git a/drivers/char/joystick/joy-logitech.c b/drivers/char/joystick/joy-logitech.c
index 2dcafbfeb..064ecade4 100644
--- a/drivers/char/joystick/joy-logitech.c
+++ b/drivers/char/joystick/joy-logitech.c
@@ -25,7 +25,7 @@
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*
* Should you need to contact me, the author, you can do so either by
* e-mail - mail your message to <vojtech@ucw.cz>, or by paper mail:
* Vojtech Pavlik, Ucitelska 1576, Prague 8, 182 00 Czech Republic
*/
@@ -318,7 +318,7 @@ static struct js_port __init *js_lt_probe(int io, struct js_port *port)
return port;
default:
printk(KERN_WARNING "joy-logitech: unknown joystick device detected "
- "(io=%#x, count=%d, data=0x%08x%08x), contact <vojtech@ucw.cz>\n",
+ "(io=%#x, count=%d, data=0x%08x%08x), contact <vojtech@suse.cz>\n",
io, i, (int)(data >> 32), (int)(data & 0xffffffff));
return port;
}
@@ -25,7 +25,7 @@
*
* Should you need to contact me, the author, you can do so either by
- * e-mail - mail your message to <vojtech@ucw.cz>, or by paper mail:
+ * e-mail - mail your message to <vojtech@suse.cz>, or by paper mail:
* Vojtech Pavlik, Ucitelska 1576, Prague 8, 182 00 Czech Republic
*/
diff --git a/drivers/char/joystick/joy-sidewinder.c b/drivers/char/joystick/joy-sidewinder.c
index 3fb0d8cef..d097471bc 100644
--- a/drivers/char/joystick/joy-sidewinder.c
+++ b/drivers/char/joystick/joy-sidewinder.c
@@ -25,7 +25,7 @@
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*
* Should you need to contact me, the author, you can do so either by
* e-mail - mail your message to <vojtech@ucw.cz>, or by paper mail:
* Vojtech Pavlik, Ucitelska 1576, Prague 8, 182 00 Czech Republic
*/
@@ -422,7 +422,7 @@ static struct js_port __init *js_sw_probe(int io, struct js_port *port)
return port;
default:
printk(KERN_WARNING "joy-sidewinder: unknown joystick device detected "
- "(io=%#x, count=%d, data=0x%08x%08x), contact <vojtech@ucw.cz>\n",
+ "(io=%#x, count=%d, data=0x%08x%08x), contact <vojtech@suse.cz>\n",
io, i, (int)(data >> 32), (int)(data & 0xffffffff));
return port;
}
@@ -25,7 +25,7 @@
*
* Should you need to contact me, the author, you can do so either by
- * e-mail - mail your message to <vojtech@ucw.cz>, or by paper mail:
+ * e-mail - mail your message to <vojtech@suse.cz>, or by paper mail:
* Vojtech Pavlik, Ucitelska 1576, Prague 8, 182 00 Czech Republic
*/
diff --git a/drivers/char/joystick/joy-thrustmaster.c b/drivers/char/joystick/joy-thrustmaster.c
index 3ea71416d..1e79b3281 100644
--- a/drivers/char/joystick/joy-thrustmaster.c
+++ b/drivers/char/joystick/joy-thrustmaster.c
@@ -25,7 +25,7 @@
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*
* Should you need to contact me, the author, you can do so either by
* e-mail - mail your message to <vojtech@ucw.cz>, or by paper mail:
* Vojtech Pavlik, Ucitelska 1576, Prague 8, 182 00 Czech Republic
*/
@@ -278,7 +278,7 @@ static struct js_port __init *js_tm_probe(int io, struct js_port *port)
if (info.mode >= JS_TM_MODE_MAX || !names[info.mode]) {
printk(KERN_WARNING "joy-thrustmaster: unknown device detected "
- "(io=%#x, id=%d), contact <vojtech@ucw.cz>\n",
+ "(io=%#x, id=%d), contact <vojtech@suse.cz>\n",
io, info.mode);
return port;
}
@@ -25,7 +25,7 @@
*
* Should you need to contact me, the author, you can do so either by
- * e-mail - mail your message to <vojtech@ucw.cz>, or by paper mail:
+ * e-mail - mail your message to <vojtech@suse.cz>, or by paper mail:
* Vojtech Pavlik, Ucitelska 1576, Prague 8, 182 00 Czech Republic
*/
diff --git a/drivers/char/joystick/joy-turbografx.c b/drivers/char/joystick/joy-turbografx.c
index fdf1aa433..6b30efe85 100644
--- a/drivers/char/joystick/joy-turbografx.c
+++ b/drivers/char/joystick/joy-turbografx.c
@@ -26,7 +26,7 @@
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*
* Should you need to contact me, the author, you can do so either by
* e-mail - mail your message to <vojtech@ucw.cz>, or by paper mail:
* Vojtech Pavlik, Ucitelska 1576, Prague 8, 182 00 Czech Republic
*/
@@ -41,7 +41,7 @@
#include <linux/delay.h>
-MODULE_AUTHOR("Vojtech Pavlik <vojtech@ucw.cz>");
+MODULE_AUTHOR("Vojtech Pavlik <vojtech@suse.cz>");
MODULE_PARM(js_tg, "2-8i");
MODULE_PARM(js_tg_2, "2-8i");
MODULE_PARM(js_tg_3, "2-8i");
@@ -26,7 +26,7 @@
*
* Should you need to contact me, the author, you can do so either by
- * e-mail - mail your message to <vojtech@ucw.cz>, or by paper mail:
+ * e-mail - mail your message to <vojtech@suse.cz>, or by paper mail:
* Vojtech Pavlik, Ucitelska 1576, Prague 8, 182 00 Czech Republic
*/
diff --git a/drivers/char/joystick/joystick.c b/drivers/char/joystick/joystick.c
index 941f1795d..6c2abda1f 100644
--- a/drivers/char/joystick/joystick.c
+++ b/drivers/char/joystick/joystick.c
@@ -26,7 +26,7 @@
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*
* Should you need to contact me, the author, you can do so either by
* e-mail - mail your message to <vojtech@ucw.cz>, or by paper mail:
* Vojtech Pavlik, Ucitelska 1576, Prague 8, 182 00 Czech Republic
*/
@@ -90,7 +90,7 @@ js_delta_func js_delta_a;
* Module info.
*/
-MODULE_AUTHOR("Vojtech Pavlik <vojtech@ucw.cz>");
+MODULE_AUTHOR("Vojtech Pavlik <vojtech@suse.cz>");
MODULE_SUPPORTED_DEVICE("js");
/*
@@ -26,7 +26,7 @@
*
* Should you need to contact me, the author, you can do so either by
- * e-mail - mail your message to <vojtech@ucw.cz>, or by paper mail:
+ * e-mail - mail your message to <vojtech@suse.cz>, or by paper mail:
* Vojtech Pavlik, Ucitelska 1576, Prague 8, 182 00 Czech Republic
*/